#########
 Schemas
#########

This module defines pydantic schemas, which are used to validate the
configuration before a training run is started. The top-level config
yaml matches the BaseSchema.

.. automodule:: anemoi.training.schemas.base_schema
   :members:
   :no-undoc-members:
   :show-inheritance:

The below schemas are organised below identically to the training config
files,

******
 Data
******

.. automodule:: anemoi.training.schemas.data
   :members:
   :no-undoc-members:
   :show-inheritance:

************
 Dataloader
************

.. automodule:: anemoi.training.schemas.dataloader
   :members:
   :no-undoc-members:
   :show-inheritance:

*************
 Diagnostics
*************

.. automodule:: anemoi.training.schemas.diagnostics
   :members:
   :no-undoc-members:
   :show-inheritance:

********
 System
********

.. automodule:: anemoi.training.schemas.system
   :members:
   :no-undoc-members:
   :show-inheritance:

*******
 Graph
*******

.. automodule:: anemoi.graphs.schemas.base_graph
   :members:
   :no-undoc-members:
   :show-inheritance:

*******
 Model
*******

.. automodule:: anemoi.models.schemas.models
   :members:
   :no-undoc-members:
   :show-inheritance:

**********
 Training
**********

.. automodule:: anemoi.training.schemas.training
   :members:
   :no-undoc-members:
   :show-inheritance:
